@@ -1,6 +1,7 @@
 # The contents of this file is free and unencumbered software released into the
 # public domain. For more information, please refer to <http://unlicense.org/>
 
+from anilistWrapPY.errors.types import Error
 from dataclasses import dataclass
 from typing import Optional, Any, List
 
@@ -117,6 +118,7 @@ class Data:
 @dataclass
 class AnilistAiring:
     data: Optional[Data] = None
+    errors: Optional[List[Error]] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'AnilistAiring':
@@ -128,11 +130,3 @@ class AnilistAiring:
         result: dict = {}
         result["data"] = from_union([lambda x: to_class(Data, x), from_none], self.data)
         return result
-
-
-def anilist_airing_from_dict(s: Any) -> AnilistAiring:
-    return AnilistAiring.from_dict(s)
-
-
-def anilist_airing_to_dict(x: AnilistAiring) -> Any:
-    return to_class(AnilistAiring, x)
