@@ -1,6 +1,7 @@
 # The contents of this file is free and unencumbered software released into the
 # public domain. For more information, please refer to <http://unlicense.org/>
 
+from anilistWrapPY.errors import Error
 from dataclasses import dataclass
 from typing import Optional, Any, List
 
@@ -463,6 +464,7 @@ class Data:
 @dataclass
 class AnilistUser:
     data: Optional[Data] = None
+    errors: Optional[List[Error]] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'AnilistUser':
@@ -474,10 +476,3 @@ class AnilistUser:
         result: dict = {"data": from_union([lambda x: to_class(Data, x), from_none], self.data)}
         return result
 
-
-def anilist_user_from_dict(s: Any) -> AnilistUser:
-    return AnilistUser.from_dict(s)
-
-
-def anilist_user_to_dict(x: AnilistUser) -> Any:
-    return to_class(AnilistUser, x)
